import cn from 'classnames';
import React, {
  forwardRef,
} from 'react';
import s from './Button.module.scss';
import Loading from '@/components/common/Loading';

// eslint-disable-next-line react/display-name
const Button = forwardRef((props, buttonRef) => {
  const {
    className,
    variant = 'flat', // ghost | slim | naked
    children,
    active,
    width,
    loading = false,
    disabled = false,
    style = {},
    Component = 'button',
    ...rest
  } = props;

  const rootClassName = cn(
    s.root,
    {
      [s.ghost]: variant === 'ghost',
      [s.slim]: variant === 'slim',
      [s.naked]: variant === 'naked',
      [s.loading]: loading,
      [s.disabled]: disabled,
    },
    className
  );

  return (
    <Component
      aria-pressed={active}
      data-variant={variant}
      ref={buttonRef}
      className={rootClassName}
      disabled={disabled}
      style={{
        width,
        ...style,
      }}
      {...rest}
    >
      {children}
      {loading && (
        <i className="flex pl-2 m-0">
          <Loading />
        </i>
      )}
    </Component>
  );
});

export default Button;
