import cn from 'classnames';
import React from 'react';

const Input = (props) => {
  const { className, label, id, info, error, ...rest } = props;

  const rootClassName = cn({
    'bg-white py-2 px-3 w-full appearance-none transition duration-150 ease-in-out pr-10 border focus:outline-none focus:border-gray-900': true,
    'border-gray-300': !error,
    'border-red-500': error
  }, className);
  const inputWrapperClass = cn({
    'mb-4 w-full': true,
    'text-red-500': error
  });
  const labelClass = cn({
    'inline-block mb-1 text-gray-500': true,
    'text-red-500': error
  });
  const infoClass = cn({
    'text-[12px] text-gray-400 mt-1': true,
    'text-red-500': error
  });

  return (
    <div className={inputWrapperClass}>
      {label && <label className={labelClass} htmlFor={id}>{label}</label>}

      <input
        className={rootClassName}
        id={id}
        autoComplete="off"
        autoCorrect="off"
        spellCheck="false"
        {...rest}
      />

      {info && <div className={infoClass}>{info}</div>}
    </div>
  );
};

export default Input;
