import * as React from 'react';
import cn from 'classnames';
const TabsContext = React.createContext({ active: 0, withBorder: false });

export const Tabs = ({ active = 0, withBorder = false, children }) => (
  <TabsContext.Provider value={{ active, withBorder }}>
    <div className="w-full">{children}</div>
  </TabsContext.Provider>
);

export const TabList = ({ children, className }) => {
  const tabContext = React.useContext(TabsContext);

  const rootClass = cn('relative z-10', className);

  return (
    <div className="flex flex-col mx-auto item-center">
      <div className={rootClass}>{children}</div>
      {
        tabContext.withBorder && <div className="w-full border-b relative z-0 -mt-[1px]"/>
      }
    </div>
  );
};

export const Tab = ({ children, index, className, onClick, disabled = false }) => {
  /* hooks */
  const tabContext = React.useContext(TabsContext);

  const rootClass = cn('inline-block mr-6 text-sm tracking-widest uppercase group', className);
  const labelClass = cn('transition-all', {
    ['group-hover:text-black']: !disabled,
    ['text-black']: tabContext.active === index,
    ['text-gray-500']: tabContext.active !== index
  });
  const lineClass = cn('block h-[1px] mt-2 bg-black transition-all', {
    ['group-hover:w-[30px] ']: !disabled,
    ['w-[30px]']: tabContext.active === index,
    ['w-0']: tabContext.active !== index
  });

  const handleOnClick = () => {
    if (disabled || !onClick) return;
    onClick();
  };

  return (
    <span
      role="button"
      className={rootClass}
      onClick={handleOnClick}
    >
      <span
        className={labelClass}
      >
        {children}
      </span>
      <span
        className={lineClass}
      />
    </span>
  );
};

export const TabPanels = ({ children }) => (
  <div className="w-full">{children}</div>
);

export const TabPanel = ({ children, index }) => (
  <TabsContext.Consumer>
    {(value) =>
      value.active === index ? <div className="w-full">{children}</div> : null
    }
  </TabsContext.Consumer>
);
