import { motion } from 'framer-motion';
import IconClose from '../../../../public/images/icons/icon-close.svg';

const BackdropVariant = {
  show: {
    opacity: 1,
    transition: {
      when: 'beforeChildren',
      duration: 0.1,
      type: 'tween',
    },
  },
  hide: {
    opacity: 0,
  },
};

const SheetViewVariants = {
  show: {
    y: '0%',
    transition: {
      duration: 0.2,
      type: 'tween',
    },
  },
  hide: {
    y: '100%',
  },
};

const BottomSheet = ({ title, onClose, children }) => {
  return (
    <motion.div
      className="fixed left-0 top-0 right-0 bottom-0 z-50"
      variants={BackdropVariant}
      initial="hide"
      animate="show"
      exit="hide"
    >
      <div
        className="absolute  left-0 top-0 right-0 bottom-0 z-50 bg-black bg-opacity-30"
        onClick={onClose}
      />
      <motion.div
        className="absolute left-0 right-0 bottom-0 z-50 bg-white px-8 py-6 max-h-full overflow-y-auto"
        variants={SheetViewVariants}
      >
        <div className="flex items-center relative">
          {title && <h3 className="font-semibold text-lg">{title}</h3>}
          <button onClick={onClose} className="absolute right-0 top-0">
            <IconClose />
          </button>
        </div>
        <div className="mt-4">{children}</div>
      </motion.div>
    </motion.div>
  );
};

export default BottomSheet;
