import { useEffect, useMemo, useState } from 'react';
import Link from 'next/link';
import Image from 'next/image';
import { motion } from 'framer-motion';
import Button from '@/components/common/Button';
import { useAppProvider } from '@/context/AppProvider';
import { formatAmountWithSymbol } from '@/utils/price';
import { productGetters } from '@react-test-storefront/medusa';

const ImageVariants = {
  hover: {
    scale: 1.1,
  },
};

const ButtonVariants = {
  initial: {
    opacity: 0,
    y: '50%',
  },
  hover: {
    opacity: 1,
    y: '0%',
  },
};

const ProductCard = ({ product }) => {
  const { cartObject: { cartFunctions, cart } } = useAppProvider();
  const { isInCart: checkIsInCart } = cartFunctions();
  const [isInCart, setIsInCart] = useState(false);

  // GETTERS
  const { getName, getSlug, getPrice, getCoverImage } = productGetters;
  const name = useMemo(() => getName(product), [product]);
  const slug = useMemo(() => getSlug(product), [product]);
  const price = useMemo(() => getPrice(product, cart?.region?.currency_code), [product, cart]);
  const image = useMemo(() => getCoverImage(product), [product]);

  useEffect(() => {
    const inCart = checkIsInCart({ cart, product });
    if (inCart !== isInCart) {
      setIsInCart(inCart);
    }
  }, [product, cart]);

  return (
    <Link href={`/store/${slug}`} passHref>
      <a className="w-full" aria-label={name}>
        <div className="relative">
          <motion.div
            className="overflow-hidden relative"
            whileHover="hover"
            initial="initial"
          >
            <motion.div variants={ImageVariants}>
              <div className="relative aspect-[3/4]">
                <Image
                  src={image}
                  layout="fill"
                  objectFit="contain"
                  alt={name}
                />
              </div>
            </motion.div>
            <motion.div
              className="absolute left-0 right-0 bottom-0 hidden lg:block"
              variants={ButtonVariants}
            >
              <Button width="100%" variant="slim">
                OPEN
              </Button>
            </motion.div>
            <div className="absolute left-0 right-0 bottom-0 lg:hidden">
              <Button width="100%" variant="slim">
                OPEN
              </Button>
            </div>
          </motion.div>
          <div className="mt-4">
            <p className="font-semibold">{name}</p>
            <p className="font-light">
              {formatAmountWithSymbol({
                currency: cart?.region?.currency_code,
                amount: price?.regular,
                tax: cart?.region?.tax_rate
              })}
            </p>
          </div>
        </div>
      </a>
    </Link>
  );
};

export default ProductCard;
