import cn from 'classnames';

import IconClose from '../../../../public/images/icons/icon-close.svg';
import IconPlus from '../../../../public/images/icons/icon-plus.svg';
import IconMinus from '../../../../public/images/icons/icon-minus.svg';

const Quantity = ({
  className,
  value,
  increase,
  decrease,
  handleChange,
  handleRemove,
  max = 99,
}) => {
  const rootClass = cn('flex flex-row w-full overflow-hidden h-9 mt-3', className);
  const btnClass = cn('border-accent-2 border flex w-9 flex-shrink-0 sh justify-center items-center  fill-current text-gray-500');
  const btnAddClass = cn({
    [btnClass]: true,
    'cursor-not-allowed': +value === max,
  });
  const btnDecClass = cn({
    [btnClass]: true,
    'cursor-not-allowed': +value === 1,
  });

  const removeBtnClass = cn(btnClass, 'mr-2');

  const inputWrapperClass = cn(
    'border-accent-2 border w-full flex min-w-[100px] justify-center items-center text-center '
  );

  return (
    <div className={rootClass}>
      {handleRemove && (
        <button className={removeBtnClass} onClick={handleRemove}>
          <IconClose />
        </button>
      )}
      <label className={inputWrapperClass}>
        <input
          onChange={(e) =>
            Number(e.target.value) < max + 1 ? handleChange(e) : () => { }
          }
          value={value}
          type="text"
          max={max}
          min="0"
          readOnly
          className="text-center w-full focus:outline-none"
        />
      </label>
      <button
        className={btnDecClass}
        type="button"
        onClick={decrease}
        style={{ marginLeft: '-1px' }}
        disabled={value <= 1}
      >
        <IconMinus />
      </button>
      <button
        className={btnAddClass}
        type="button"
        onClick={increase}
        style={{ marginLeft: '-1px' }}
        disabled={value < 1 || value >= max}
      >
        <IconPlus />
      </button>
    </div>
  );
};

export default Quantity;
