
import { useState } from 'react';
import cn from 'classnames';
import Image from 'next/image';
import { motion, AnimatePresence } from 'framer-motion';
import IconArrowDown from '../../../../public/images/icons/icon-arrow-down.svg';

const ThumbnailCarousel = ({ images = null, className }) => {
  const [imageIndex, setImageIndex] = useState(0);
  const rootClass = cn('w-full flex flex-col', className);

  const handleOnNext = () => {
    if (imageIndex < images.length - 1) {
      setImageIndex(i => i + 1);
    } else {
      setImageIndex(0);
    }
  };

  const handlePrev = () => {
    if (imageIndex > 0) {
      setImageIndex(i => i - 1);
    } else {
      setImageIndex(images.length - 1);
    }
  };

  const setImageByIdx = (idx) => {
    setImageIndex(idx);
  };

  if (!images) {
    return null;
  }

  const activeImage = images[imageIndex];

  return (
    <div className={rootClass}>
      <div className="w-full aspect-[3/4] relative">
        <AnimatePresence exitBeforeEnter>
          <motion.div
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            exit={{ opacity: 0 }}
            className="relative w-full aspect-[3/4]"
            key={activeImage.id}
          >
            <Image
              src={activeImage.src}
              layout="fill"
              objectFit="contain"
              alt={activeImage.src}
            />
          </motion.div>
        </AnimatePresence>
        <div className="absolute left-0 right-0 top-[50%] flex items-center px-4">
          <motion.button
            className="flex justify-center items-center border border-black text-black"
            onClick={handleOnNext}
            whileTap={{ scale: 0.85 }}
          >
            <span className=" text-current rotate-90 ">
              <IconArrowDown />
            </span>
          </motion.button>
          <motion.button
            className="flex justify-center items-center border border-black text-black ml-auto"
            onClick={handlePrev}
            whileTap={{ scale: 0.85 }}
          >
            <span className=" text-current -rotate-90">
              <IconArrowDown />
            </span>
          </motion.button>
        </div>
      </div>
      <div className="w-full flex justify-center gap-x-2 py-6">
        {images.map((item, idx) => (
          <div
            className={`
              w-24 aspect-[3/4] relative transition-all border cursor-pointer 
              ${imageIndex === idx ? 'border-black' : 'border-transparent'}
            `}
            key={item.id}
            onClick={() => setImageByIdx(idx)}
          >
            <Image src={item} layout="fill" objectFit="contain" alt={item} />
          </div>
        ))}
      </div>
    </div>
  );
};

export default ThumbnailCarousel;
