import cn from 'classnames';
import React, { useCallback } from 'react';
import IconSearch from '../../../../../public/images/icons/icon-search.svg';
import IconClose from '../../../../../public/images/icons/icon-close.svg';

const InputSearch = (props) => {
  const {
    viewType,
    className,
    isLoading,
    onClose,
    ...rest
  } = props;

  const rootClassName = cn({
    'flex w-full items-center': true,
    'bg-white py-2 px-3 appearance-none transition duration-150 ease-in-out pr-10 border focus:outline-none focus:border-gray-900 border-gray-300': true,
    'px-[40px]': viewType === 'mobile',
    'pr-[40px]': viewType === 'desktop'
  }, className);
  const inputWrapperClass = cn({
    'mb-2 w-full relative max-w-[440px]': viewType === 'desktop',
    'mb-2 w-full relative': viewType === 'mobile',
  });
  const inputAppendClass = cn({
    'h-full w-[46px] text-gray-700': true,
    'absolute top-0 right-0 bottom-0': true,
    'flex items-center justify-center': true,
  });
  const inputPrependClass = cn({
    'h-full w-[46px] text-gray-700': true,
    'absolute top-0 left-0 bottom-0': true,
    'flex items-center justify-center': true,
  });

  const handleClose = useCallback(() => {
    if (onClose && !isLoading) {
      onClose();
    }
  }, [onClose, isLoading]);

  if (viewType === 'mobile') {
    return (
      <div className={inputWrapperClass}>
        {/* input prepend */}
        <div className={inputPrependClass}>
          <div className="w-4 h-4">
            <IconSearch />
          </div>
        </div>
        <input
          className={rootClassName}
          autoComplete="off"
          autoCorrect="off"
          spellCheck="false"
          placeholder="Search..."
          {...rest}
        />
        {/* input append */}
        <div role="button" className={inputAppendClass} onClick={handleClose}>
          <div className="w-4 h-4 flex items-center justify-center">
            {isLoading
              ? <svg className="animate-spin -ml-1 mr-3 h-5 w-5 text-current" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                <circle className="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4"></circle>
                <path className="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
              </svg>
              : <IconClose />
            }
          </div>
        </div>
      </div>
    );
  }

  return (
    <div className={inputWrapperClass}>
      <input
        className={rootClassName}
        autoComplete="off"
        autoCorrect="off"
        spellCheck="false"
        placeholder="Search..."
        {...rest}
      />
      {/* input append */}
      <div role="button" className={inputAppendClass} onClick={handleClose}>
        <div className="w-4 h-4">
          {isLoading
            ? <svg className="animate-spin -ml-1 mr-3 h-5 w-5 text-current" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
              <circle className="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4"></circle>
              <path className="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
            </svg>
            : <IconSearch />
          }
        </div>
      </div>
    </div>
  );
};

export default InputSearch;
