import React, { useEffect, useState } from 'react';
import { Menu } from '@headlessui/react';
import classNames from 'classnames';
import { useAppProvider } from '@/context/AppProvider';
import PopoverTransition from './PopoverTransition';

const ACTIVE_REGION = 'react_region';
// const ACTIVE_COUNTRY = 'react_country';

const RegionSelect = () => {
  const [activeRegion, setActiveRegion] = useState(null);
  // const [activeCountry, setActiveCountry] = useState(null);
  const {
    shippingRegionObject: { shippingRegion, shippingRegionFunctions },
    cartObject: { cart }
  } = useAppProvider();
  const { load: loadShippingRegion, save: saveShippingRegion } = shippingRegionFunctions();

  useEffect(() => {
    // const localCountry = window.localStorage.getItem(ACTIVE_COUNTRY);
    const localRegion = window.localStorage.getItem(ACTIVE_REGION);

    // if (localCountry) {
    //   setActiveCountry(localCountry);
    // }
    if (localRegion) {
      const regionObj = JSON.parse(localRegion);
      setActiveRegion(regionObj);
    }
  }, []);

  // Set the active region
  useEffect(() => {
    if (cart) {
      const tempRegion = activeRegion || cart.region;

      if (activeRegion && activeRegion?.id !== cart?.region?.id) {
        saveShippingRegion({ currentCart: cart, region: tempRegion });
      }

      // if (!activeCountry) {
      //   setActiveCountry(tempRegion?.countries[0]?.display_name);
      // }
      setActiveRegion(tempRegion);
    }
  }, [cart]);

  useEffect(() => {
    if (!shippingRegion) {
      loadShippingRegion();
    }
  }, [shippingRegion]);

  const handleSelect = async (region, country) => {
    if (!activeRegion || activeRegion.id !== region.id) {
      saveShippingRegion({ currentCart: cart, region });
      window.localStorage.setItem(ACTIVE_REGION, JSON.stringify(region));
      setActiveRegion(region);
    }
    // setActiveCountry(country);
    // window.localStorage.setItem(ACTIVE_COUNTRY, country);
  };

  if (!shippingRegion) {
    return null;
  }

  return (
    <Menu
      as="div"
      className="inline-block relative text-left"
    >
      <div>
        <Menu.Button className="inline-flex justify-center w-full px-4 py-2 bg-white text-sm font-medium text-gray-700 hover:text-gray-600">
          {activeRegion?.name?.toUpperCase()}
        </Menu.Button>
      </div>

      <PopoverTransition>
        <Menu.Items className="origin-top-right absolute right-0 mt-2 w-46 px-6 py-2 rounded-md shadow-lg bg-white ring-1 ring-black ring-opacity-5 focus:outline-none">
          {shippingRegion?.map((region) => {
            // return region.countries.map((country) => {
            return (
              <Menu.Item key={region.id}>
                {() => (
                  <button
                    onClick={() => handleSelect(region)}
                    className={classNames(
                      region.id === activeRegion.id
                        ? 'text-black'
                        : 'text-ui-dark',
                      'block py-3 text-sm w-full text-left hover:text-black'
                    )}
                  >
                    {region.name.toUpperCase()}
                  </button>
                )}
              </Menu.Item>
            );

            // return (
            //   <div className="border-b border-ui last:border-b-0" key={i}>
            //     <Menu.Item>
            //       {() => (
            //         <button
            //           onClick={() => handleSelect(region, country.display_name)}
            //           className={classNames(
            //             country === country.display_name
            //               ? 'text-black'
            //               : 'text-ui-dark',
            //             'block py-3 text-sm w-full text-left hover:text-black'
            //           )}
            //         >
            //           {country.display_name} /{' '}
            //           {region.currency_code.toUpperCase()}
            //         </button>
            //       )}
            //     </Menu.Item>
            //   </div>
            // );
            // });
          })}
        </Menu.Items>
      </PopoverTransition>
    </Menu>
  );
};

export default RegionSelect;

