import Image from 'next/image';
import Link from 'next/link';
import IconSearch from '../../../../../public/images/icons/icon-search.svg';

const SearchItem = (props) => {
  const {
    type = 'keyword', // keyword | item
    imgSrc = '/images/misc/product-placeholder.png',
    imgAlt = 'Product Placeholder',
    href = '#',
    label = ''
  } = props;

  if (type === 'keyword') {
    return (
      <Link href={href}>
        <a className="group">
          <div className="flex w-full overflow-hidden items-start gap-3">
            <div className="flex-initial w-[40px] h-[40px] flex items-center justify-center bg-gray-100">
              <div className="h-5 w-5 text-gray-400">
                <IconSearch />
              </div>
            </div>
            <div className="flex-auto min-h-[40px] pt-2 pl-2 group-hover:bg-gray-100">
              <div className="text-[14px]">{label}</div>
            </div>
          </div>
        </a>
      </Link>
    );
  }

  return (
    <Link href={href}>
      <a className="group">
        <div className="flex w-full overflow-hidden items-start gap-3">
          <div className="flex-initial w-[40px] h-[40px] relative">
            <Image
              src={imgSrc}
              alt={imgAlt}
              layout="fill"
              objectFit="cover"
              objectPosition="center"
            />
          </div>
          <div className="flex-auto min-h-[40px] pt-2 pl-2 group-hover:bg-gray-100">
            <div className="text-[14px]">{label}</div>
          </div>
        </div>
      </a>
    </Link>
  );
};

export default SearchItem;
