import React from 'react';
import Logo from '../../../../public/images/logo.svg';
import Link from 'next/link';
import PaymentAmex from '../../../../public/images/payments/payment-amex.svg';
import PaymentApplePay from '../../../../public/images/payments/payment-apple-pay.svg';
import PaymentDinerClub from '../../../../public/images/payments/payment-diner-club.svg';
import PaymentDiscover from '../../../../public/images/payments/payment-discover.svg';
import PaymentGooglePay from '../../../../public/images/payments/payment-google-pay.svg';
import PaymentMaestro from '../../../../public/images/payments/payment-maestro.svg';
import PaymentMaster from '../../../../public/images/payments/payment-master.svg';
import PaymentShopify from '../../../../public/images/payments/payment-shopify-pay.svg';
import PaymentVisa from '../../../../public/images/payments/payment-visa.svg';

const PaymentMethod = () => (
  <ul className="flex flex-wrap mt-6">
    <li className="mr-2">
      <PaymentAmex />
    </li>
    <li className="mr-2">
      <PaymentApplePay />
    </li>
    <li className="mr-2">
      <PaymentDinerClub />
    </li>
    <li className="mr-2">
      <PaymentDiscover />
    </li>
    <li className="mr-2">
      <PaymentGooglePay />
    </li>
    <li className="mr-2">
      <PaymentMaestro />
    </li>
    <li className="mr-2">
      <PaymentMaster />
    </li>
    <li className="mr-2">
      <PaymentShopify />
    </li>
    <li className="mr-2">
      <PaymentVisa />
    </li>
  </ul>
);
const FooterMenuItem = ({ link, label }) => (
  <Link href={link} passHref>
    <a className="mb-2 text-sm tracking-widest text-gray-500 transition-all hover:text-black">
      {label}
    </a>
  </Link>
);
const FooterMenu = () => (
  <nav className="flex flex-col mt-8 lg:mt-0">
    <FooterMenuItem label="Abous Us" link="/" />
    <FooterMenuItem label="FAQs" link="/" />
    <FooterMenuItem label="Press" link="/" />
    <FooterMenuItem label="Contact Us" link="/" />
    <FooterMenuItem label="Privacy policy" link="/" />
  </nav>
);
const SubscribeForm = () => (
  <div>
    <h2 className="text-3xl font-semibold">
      Want to know when we release <br className="hidden lg:block" />
      new items and promotions?
    </h2>
    <input
      className="w-full px-4 py-2 mt-6 border border-black outline-none"
      placeholder="Email..."
      type="email"
    />
    <button className="px-4 py-2 mt-3 text-sm tracking-widest text-white uppercase bg-black hover:bg-gray-800">
      Subscribe to newsletter
    </button>
  </div>
);

const Footer = () => (
  <footer className="w-full pt-16 pb-8 border-t">
    <div className="container mx-auto">
      {/* Mobile */}
      <div className="grid grid-cols-1 lg:hidden">
        <div className="col-span-1">
          <Link href="/" passHref>
            <a className="inline-block mb-6 w-[150px]">
              <Logo width="100%" />
            </a>
          </Link>
          <SubscribeForm />
          <FooterMenu />
          <PaymentMethod />
        </div>
      </div>

      {/* Desktop */}
      <div className="hidden lg:grid lg:grid-cols-7 lg:grid-rows-1">
        <div className="lg:col-span-3">
          <Link href="/" passHref>
            <a className="inline-block mb-6 w-[150px]">
              <Logo width="100%" />
            </a>
          </Link>
          <FooterMenu />
          <PaymentMethod />
        </div>
        <div className="lg:col-span-4">
          <SubscribeForm />
        </div>
      </div>
    </div>
    <div className="container mx-auto mt-12">
      <div className="grid grid-cols-1 grid-rows-2 lg:grid-cols-2 lg:grid-rows-1">
        <div className="col-span-1 text-gray-500">
          <p>
            Copyright 2022. Made by{' '}
            <a className="text-black" href="kappa.london" target="_blank">
              kappa.london
            </a>
          </p>
        </div>
      </div>
    </div>
  </footer>
);

export default Footer;
