import { useRouter } from 'next/router';
import Link from 'next/link';
import cn from 'classnames';

const menus = [
  {
    label: 'My Profile',
    route: 'my-profile',
  },
  {
    label: 'Shipping Details',
    route: 'shipping-details',
  },
  {
    label: 'Order History',
    route: 'order-history',
  },
];

const MenuItem = (props) => {
  const { link, label, active } = props;
  const rootClass =
    cn('hover:text-black transition-all py-2',
      {
        ['text-black']: active,
        ['text-gray-500']: !active,
      });

  return (
    <Link href={link} passHref>
      <a className={rootClass}>{label}</a>
    </Link>
  );
};

const AccountMenu = () => {
  const router = useRouter();
  const activePage = router.asPath.split('/')[2] || 'my-profile';

  return (
    <div className="w-full h-full p-12 bg-gray-100">
      <h3 className="text-lg font-semibold">My Account</h3>
      <nav className="grid grid-flow-row mt-6">
        {menus.map(({ label, route }) => (
          <MenuItem
            key={route}
            active={route === activePage}
            label={label}
            link={`/account/${route}`}
          />
        ))}
      </nav>
    </div>
  );
};

export default AccountMenu;
