import { useMemo } from 'react';
import Link from 'next/link';
import CartItem from './CartItem';
import { cartGetters } from '@react-test-storefront/medusa';
import { useAppProvider } from '@/context/AppProvider';

const CartReview = () => {
  const { cartObject: { cart } } = useAppProvider();
  const cartItems = useMemo(() => cartGetters.getItems(cart), [cart]);

  const hasItems = cartItems && cartItems.length > 0;

  if (!cart) {
    return null;
  }
  return (
    <div className="w-full">
      <h3 className="text-lg font-semibold mb-8">Cart</h3>
      {hasItems
        ? <ul className="w-full">
          {cartItems.map((item) => (
            <CartItem variant="advanced" key={item.id} item={item} />
          ))}
        </ul>
        : (
          <>
            <h3>Your cart is empty</h3>
            <Link href={'/store'}>
              <a className="text-blue-600">Go to Store</a>
            </Link>
          </>
        )
      }
    </div>
  );
};

export default CartReview;
