import Link from 'next/link';
import { useMemo } from 'react';
import Button from '@/components/common/Button';
import { useAppProvider } from '@/context/AppProvider';
import { cartGetters } from '@react-test-storefront/medusa';
import { formatAmountWithSymbol } from '@/utils/price';

const CartSummary = ({ hideButton = false }) => {
  const { cartObject: { cart } } = useAppProvider();
  const cartTotal = useMemo(() => cartGetters.getTotals(cart), [cart]);
  const totalItems = useMemo(() => cartGetters.getTotalItems(cart), [cart]);

  return (
    <div className="w-full mt-8 lg:mt-0">
      <h3 className="text-lg font-semibold">Summary</h3>
      <ul className="flex flex-col w-full my-4 gap-y-2">
        <li className="flex">
          <span className="text-gray-500">
            {totalItems} Products
          </span>
        </li>
        <li className="flex">
          <span className="text-gray-500">Subtotal</span>
          <span className="ml-auto">
            {formatAmountWithSymbol({ amount: cartTotal?.subtotal, currency: cart?.region?.currency_code })}
          </span>
        </li>
        <li className="flex">
          <span className="text-gray-500">Taxes</span>
          <span className="ml-auto">
            {formatAmountWithSymbol({ amount: cartTotal?.taxes, currency: cart?.region?.currency_code })}
          </span>
        </li>
        <li className="flex pb-2">
          <span className="text-gray-500">Shipping</span>
          <span className="ml-auto ">
            {formatAmountWithSymbol({ amount: cartTotal?.shipping, currency: cart?.region?.currency_code })}
          </span>
        </li>
        <li className="flex items-center pt-4 font-semibold border-t border-t-gray-200">
          <span className="text-gray-500">Total</span>
          <span className="ml-auto text-xl">
            {formatAmountWithSymbol({ amount: cartTotal?.total, currency: cart?.region?.currency_code })}
          </span>
        </li>
      </ul>
      {!hideButton && (
        <Link href="/checkout" passHref>
          <Button width="100%" Component="a">
            Checkout
          </Button>
        </Link>
      )}
    </div>
  );
};

export default CartSummary;
