import React, { useEffect } from 'react';
import Dropdown from '@/components/common/Dropdown';
import Input from '@/components/common/Form/Input';
import Checkbox from '@/components/common/Form/Checkbox';
import { useAppProvider } from '@/context/AppProvider';

const Billing = ({ sameAddress = true, setSameAddress, handleBillingAddress }) => {
  const {
    billingObject: { billing, billingFunctions },
    cartObject: { cart },
  } = useAppProvider();

  const { load: loadBilling } = billingFunctions();

  useEffect(() => {
    if (cart && !billing) {
      loadBilling(cart);
    }
  }, [cart]);

  const {
    errors,
    handleChange,
    setFieldTouched,
    setFieldValue,
    touched,
    values,
  } = handleBillingAddress;

  useEffect(() => {
    if (billing && billing !== undefined) {
      Object.keys(billing).forEach((key) => {
        setFieldValue(key, billing[key], true);
      });
    }
  }, [billing]);

  return (
    <div className="Billing">
      <div className="w-full">
        <h3 className="text-xl font-semibold">BILLING DETAILS</h3>
        <Checkbox
          label="Use the same address for billing"
          className="my-2"
          onChange={() => setSameAddress(!sameAddress)}
          checked={sameAddress}
        />
        {!sameAddress && (
          <div className="my-6">
            <h4 className="mb-2 font-semibold">ADDRESS</h4>
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-x-6">
              <div className="lg:col-span-2">
                <Input
                  label="Street Address 1"
                  id="address1"
                  name="address1"
                  value={values.address1}
                  onBlur={() => setFieldTouched('address1')}
                  onChange={handleChange}
                  error={touched.address1 && errors.address1}
                  info={touched.address1 && errors.address1}
                />
              </div>
              <div className="lg:col-span-2">
                <Input
                  label="Street Address 2"
                  id="address2"
                  name="address2"
                  value={values.address2}
                  onBlur={() => setFieldTouched('address2')}
                  onChange={handleChange}
                  error={touched.address2 && errors.address2}
                  info={touched.address2 && errors.address2}
                />
              </div>
              <Dropdown
                label="Country"
                placeholder="Select Country"
                selected={values.country}
                onSelect={(option) => {
                  setFieldValue('country', option?.value);
                }}
                onHide={() => setFieldTouched('country')}
                error={touched.country && errors.country}
                info={touched.country && errors.country}
              >
                {cart?.region?.countries.map((country) => (
                  <Dropdown.Item
                    key={country.id}
                    label={country.name}
                    value={country.iso_2}
                  />
                ))}
              </Dropdown>
              <Input
                type="text"
                label="State/Province"
                placeholder="Select State/Province"
                id="state"
                name="state"
                value={values.state}
                onBlur={() => setFieldTouched('state')}
                onChange={handleChange}
                error={touched.state && errors.state}
                info={touched.state && errors.state}
              />

              <Input
                type="text"
                label="City"
                placeholder="Select City"
                id="city"
                name="city"
                value={values.city}
                onBlur={() => setFieldTouched('city')}
                onChange={handleChange}
                error={touched.city && errors.city}
                info={touched.city && errors.city}
              />
              <Input
                label="Zip/Postal Code"
                id="postalCode"
                name="postalCode"
                value={values.postalCode}
                onBlur={() => setFieldTouched('postalCode')}
                onChange={handleChange}
                error={touched.postalCode && errors.postalCode}
                info={touched.postalCode && errors.postalCode}
              />
            </div>
          </div>
        )}
      </div>
    </div >
  );
};

export default Billing;
