import React, { useEffect } from 'react';
import Dropdown from '@/components/common/Dropdown';
import Input from '@/components/common/Form/Input';
import { useAppProvider } from '@/context/AppProvider';

const Shipping = ({ handleShippingAddress }) => {
  const {
    shippingObject: { shipping, shippingFunctions },
    cartObject: { cart },
  } = useAppProvider();

  const { load: loadShipping } = shippingFunctions();

  useEffect(() => {
    if (cart && !shipping) {
      loadShipping(cart);
    }
  }, [cart]);

  const {
    errors,
    handleChange,
    setFieldTouched,
    setFieldValue,
    touched,
    values,
  } = handleShippingAddress;

  useEffect(() => {
    if (shipping && shipping !== undefined) {
      Object.keys(shipping).forEach((key) => {
        setFieldValue(key, shipping[key], true);
      });
    }
  }, [shipping]);

  return (
    <div className="Shipping">
      <div className="w-full">
        <h3 className="text-xl font-semibold">SHIPPING DETAILS</h3>

        {/* Contact Information */}
        <div className="my-6">
          <h4 className="mb-2 font-semibold">CONTACT INFORMATION</h4>
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-x-6">
            <Input
              type="text"
              label="First Name"
              id="firstName"
              name="firstName"
              value={values.firstName}
              onBlur={() => setFieldTouched('firstName')}
              onChange={handleChange}
              error={touched.firstName && errors.firstName}
              info={touched.firstName && errors.firstName}
            />
            <Input
              type="text"
              label="Last Name"
              id="lastName"
              name="lastName"
              value={values.lastName}
              onBlur={() => setFieldTouched('lastName')}
              onChange={handleChange}
              error={touched.lastName && errors.lastName}
              info={touched.lastName && errors.lastName}
            />
            <Input
              type="text"
              label="Email"
              id="email"
              name="email"
              value={values.email}
              onBlur={() => setFieldTouched('email')}
              onChange={handleChange}
              error={touched.email && errors.email}
              info={touched.email && errors.email}
            />
            <Input
              type="text"
              label="Phone Number"
              id="phone"
              name="phone"
              value={values.phone}
              onBlur={() => setFieldTouched('phone')}
              onChange={handleChange}
              error={touched.phone && errors.phone}
              info={touched.phone && errors.phone}
            />
          </div>
        </div>

        {/* ADDRESS */}
        <div className="my-6">
          <h4 className="mb-2 font-semibold">ADDRESS</h4>
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-x-6">
            <div className="lg:col-span-2">
              <Input
                type="text"
                label="Street Address 1"
                id="address1"
                name="address1"
                value={values.address1}
                onBlur={() => setFieldTouched('address1')}
                onChange={handleChange}
                error={touched.address1 && errors.address1}
                info={touched.address1 && errors.address1}
              />
            </div>
            <div className="lg:col-span-2">
              <Input
                type="text"
                label="Street Address 2"
                id="address2"
                name="address2"
                value={values.address2}
                onBlur={() => setFieldTouched('address2')}
                onChange={handleChange}
                error={touched.address2 && errors.address2}
                info={touched.address2 && errors.address2}
              />
            </div>
            <Dropdown
              label="Country"
              placeholder="Select Country"
              selected={values.country}
              onSelect={(option) =>
                setFieldValue('country', option?.value)
              }
              onHide={() => setFieldTouched('country')}
              error={touched.country && errors.country}
              info={touched.country && errors.country}
            >
              {cart?.region?.countries.map((country) => (
                <Dropdown.Item
                  key={country.id}
                  label={country.name}
                  value={country.iso_2}
                />
              ))}
            </Dropdown>
            <Input
              type="text"
              label="State/Province"
              placeholder="Select State/Province"
              id="state"
              name="state"
              value={values.state}
              onBlur={() => setFieldTouched('state')}
              onChange={handleChange}
              error={touched.state && errors.state}
              info={touched.state && errors.state}
            />

            <Input
              type="text"
              label="City"
              placeholder="Select City"
              id="city"
              name="city"
              value={values.city}
              onBlur={() => setFieldTouched('city')}
              onChange={handleChange}
              error={touched.city && errors.city}
              info={touched.city && errors.city}
            />
            <Input
              type="text"
              label="Zip/Postal Code"
              id="postalCode"
              name="postalCode"
              value={values.postalCode}
              onBlur={() => setFieldTouched('postalCode')}
              onChange={handleChange}
              error={touched.postalCode && errors.postalCode}
              info={touched.postalCode && errors.postalCode}
            />
          </div>
        </div>
      </div>
    </div >
  );
};

export default Shipping;
