import LayoutCheckout from '@/components/templates/LayoutCheckout';
import { useState, useEffect } from 'react';

import CheckoutTabs from './partials/CheckoutTabs';

import Address from './Address';
import Payment from './Payment';
import ShippingMethods from './ShippingMethods';

import { ADDRESS, SHIPPING, PAYMENT } from './constants';
import ThankYou from './ThankYou';

/**
 * @param {*} step address | shipping | payment
 */
const CheckoutContainer = () => {
  const [step, setStep] = useState(ADDRESS);

  /* state */
  const [complete, setComplete] = useState({
    address: 0,
    shipping: 0,
    payment: 0,
    done: 0,
  });

  useEffect(() => {
    window.scrollTo({ top: 0 });
  }, [step]);

  /* renderer */
  const renderContent = (() => {
    switch (step) {
      case ADDRESS:
        return (
          <Address setStep={setStep} step={step} setComplete={setComplete} complete={complete} />
        );
      case PAYMENT:
        return (
          <Payment setStep={setStep} step={step} setComplete={setComplete} />
        );
      case SHIPPING:
        return (
          <ShippingMethods setStep={setStep} step={step} setComplete={setComplete} />
        );

      default:
        return null;
    }
  })();

  if (complete.payment) {
    return <ThankYou />;
  }

  return (
    <LayoutCheckout title="CheckoutContainer">
      <CheckoutTabs
        addressActive={!step || step === ADDRESS}
        addressDisabled={!complete.address}
        shippingActive={step === SHIPPING}
        shippingDisabled={!complete.shipping}
        paymentActive={step === PAYMENT}
        paymentDisabled={!complete.payment}
        setStep={setStep}
      />
      <div className="border-b -mt-[1px]" />

      {renderContent}
    </LayoutCheckout>
  );
};

export default CheckoutContainer;
