import React, { useMemo } from 'react';
import { cartGetters, userShippingGetters } from '@react-test-storefront/medusa';
import CartSummary from '../CartContainer/partials/CartSummary';
import CheckoutItem from './partials/CheckoutItem';
import PaymentMethods from './PaymentMethods';
import { ADDRESS } from './constants';
import { useAppProvider } from '../../context/AppProvider';

const Payment = ({ setComplete, setStep }) => {
  /* setup */
  const {
    cartObject: {
      cart,
    },
    shippingObject: { shipping },
    billingObject: { billing },
  } = useAppProvider();
  const cartItems = useMemo(() => cartGetters.getItems(cart), []);

  const {
    getShippingMethod,
    getFirstName,
    getLastName,
    getPhone,
    getAddress1,
    getAddress2,
    getCity,
    getState,
    getCountry,
  } = userShippingGetters;
  const shippingMethod = useMemo(() => getShippingMethod(shipping), [shipping]);
  const shippingFirstName = useMemo(() => getFirstName(shipping), [shipping]);
  const shippingLastName = useMemo(() => getLastName(shipping), [shipping]);
  const shippingPhone = useMemo(() => getPhone(shipping), [shipping]);
  const shippingAddress1 = useMemo(() => getAddress1(shipping), [shipping]);
  const shippingAddress2 = useMemo(() => getAddress2(shipping), [shipping]);
  const shippingCity = useMemo(() => getCity(shipping), [shipping]);
  const shippingState = useMemo(() => getState(shipping), [shipping]);
  const shippingCountry = useMemo(() => getCountry(shipping), [shipping]);
  const billingAddress1 = useMemo(() => getAddress1(billing), [billing]);
  const billingAddress2 = useMemo(() => getAddress2(billing), [billing]);
  const billingCity = useMemo(() => getCity(billing), [billing]);
  const billingState = useMemo(() => getState(billing), [billing]);
  const billingCountry = useMemo(() => getCountry(billing), [billing]);

  return (
    <div className="Payment container mx-auto mt-12">
      <div className="grid grid-cols-12 lg:gap-x-16">
        <div className="col-span-12 md:col-span-8">
          <div className="w-full">
            <h3 className="text-xl font-semibold mb-5">PAYMENT</h3>

            <section>
              <div className="flex justify-between items-center">
                <h4 className="mb-2 font-semibold">SHIPPING</h4>
                <button
                  type="button"
                  className="text-[14px]"
                  onClick={() => setStep(ADDRESS)}
                >
                  Edit
                </button>
              </div>
              <h5 className="mb-1 font-semibold">
                {shippingMethod}
              </h5>
              <div className="text-gray-500">
                {shippingFirstName} {shippingLastName}
              </div>
              <div className="text-gray-500">{shippingPhone}</div>
              <div className="text-gray-500">{shippingAddress1}</div>
              <div className="text-gray-500">{shippingAddress2}</div>
              <div className="text-gray-500">
                {shippingCity}, {shippingState}, {shippingCountry}
              </div>
            </section>

            <hr className="my-5" />

            <section>
              <div className="flex justify-between items-center">
                <h4 className="mb-2 font-semibold">BILLING</h4>
                <button
                  type="button"
                  className="text-[14px]"
                  onClick={() => setStep(ADDRESS)}
                >
                  Edit
                </button>
              </div>
              <div className="text-gray-500">{billingAddress1}</div>
              <div className="text-gray-500">{billingAddress2}</div>
              <div className="text-gray-500">
                {billingCity}, {billingState}, {billingCountry}
              </div>
            </section>

            <hr className="my-5" />

            <section className="mb-5">
              <div className="flex justify-between items-center">
                <h4 className="mb-2 font-semibold">ITEMS</h4>
              </div>
              {cartItems.map((item) => (
                <CheckoutItem
                  key={item.id}
                  item={item}
                />
              ))}
            </section>

            <hr className="my-5" />

            <PaymentMethods setComplete={setComplete} />
          </div>
        </div>
        <div className="col-span-12 mb-16 md:col-span-4">
          <CartSummary hideButton />
        </div>
      </div>
    </div>
  );
};

export default Payment;
