import React, { useMemo } from 'react';
import { Elements } from '@stripe/react-stripe-js';
import { loadStripe } from '@stripe/stripe-js';
import InjectableCardForm from './injectable-card-form';
import { useAppProvider } from '@/context/AppProvider';

const STRIPE_KEY = process.env.STRIPE_API;
const stripePromise = loadStripe(STRIPE_KEY);

const StripePayment = ({ setComplete }) => {
  const { cartObject: { cart } } = useAppProvider();

  const stripeSession = useMemo(() => {
    if (cart.payment_sessions) {
      return cart.payment_sessions.find(s => s.provider_id === 'stripe');
    }

    return null;
  }, [cart.payment_sessions]);

  if (!stripeSession) {
    return null;
  }

  // const options = {
  //   client_secret: stripeSession.data.client_secret,
  // };

  return (
    <Elements stripe={stripePromise}>
      <InjectableCardForm session={stripeSession} setComplete={setComplete} />
    </Elements>
  );
};

export default StripePayment;
