import React, { useEffect } from 'react';
import { useAppProvider } from '@/context/AppProvider';
import Checkbox from '@/components/common/Form/Checkbox';

import StripePayment from './Stripe';
import ManualPayment from './ManualPayment';

const PaymentMethods = ({ setComplete }) => {
  const {
    cartObject: { cart },
    paymentObject: { paymentOptions, paymentFunctions },
  } = useAppProvider();
  const { load: loadPayment, select: selectPayment } = paymentFunctions();

  useEffect(() => {
    loadPayment({ currentCart: cart });
  }, []);

  const handleChange = (paymentId) => {
    selectPayment({ currentCart: cart, paymentId: paymentId });
  };

  const renderPaymentOptions = () => {
    const payment_session = cart?.payment_session;

    if (!payment_session) {
      return null;
    }

    switch (payment_session?.provider_id) {
      case 'stripe':
        return <StripePayment setComplete={setComplete} />;
      case 'manual':
        return <ManualPayment setComplete={setComplete} />;
      default:
        return null;
    }
  };

  return (
    <div className="PaymentMethods">
      <h4 className="mb-2 font-semibold">PAYMENT METHODS</h4>

      <div className="my-6">
        {paymentOptions && paymentOptions.length > 0
          ? (
            <div>
              {paymentOptions.map((option) => {
                return (
                  <Checkbox
                    key={option.id}
                    label={option.provider_id}
                    checked={cart?.payment_session?.provider_id === option.provider_id}
                    onChange={() => handleChange(option.provider_id)}
                  />
                );
              })}
            </div>
          ) : (
            <div className="flex items-center py-4 justify-center">
              <svg
                className="animate-spin h-5 w-5 text-white"
                xmlns="http://www.w3.org/2000/svg"
                fill="none"
                viewBox="0 0 24 24"
              >
                <circle
                  className="opacity-25"
                  cx="12"
                  cy="12"
                  r="10"
                  stroke="currentColor"
                  strokeWidth="4"
                ></circle>
                <path
                  className="opacity-75"
                  fill="currentColor"
                  d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"
                ></path>
              </svg>
              <div />
            </div>
          )
        }
      </div>

      {renderPaymentOptions()}
    </div>
  );
};

export default PaymentMethods;
