import React, { useEffect } from 'react';
import { useFormik } from 'formik';
import CartSummary from '../CartContainer/partials/CartSummary';
import Checkbox from '@/components/common/Form/Checkbox';
import Button from '@/components/common/Button';
import { useAppProvider } from '@/context/AppProvider';
import { validationShippingMethods } from './validation';
import { PAYMENT } from './constants';
import { formatAmountWithSymbol } from '@/utils/price';

const ShippingMethods = ({ setComplete, setStep }) => {
  const {
    shippingProviderObject: { shippingProvider, shippingProviderFunctions },
    cartObject: { cart }
  } = useAppProvider();
  const { load: loadShippingProvider, save: saveShippingProvider } = shippingProviderFunctions();

  const handleShipping = useFormik({
    initialValues: {
      shippingMethod: '',
    },
    validationSchema: validationShippingMethods,
    validateOnChange: true,
    onSubmit: async (values) => {
      await saveShippingProvider({ currentCart: cart, shippingMethod: values.shippingMethod });

      setComplete((prev) => ({ ...prev, shipping: 1 }));
      setStep(PAYMENT);
    },
  });

  useEffect(() => {
    setComplete((prev) => ({
      ...prev,
      shipping: 0,
      payment: 0,
      done: 0,
    }));
    if (cart?.shipping_methods?.length > 0) {
      handleShipping.setFieldValue('shippingMethod', cart.shipping_methods[0].shipping_option_id);
    }
  }, []); // eslint-disable-line

  useEffect(() => {
    if (!shippingProvider) {
      loadShippingProvider({
        currentCart: cart,
        isReturn: false
      });
    }
  }, [cart, shippingProvider]);

  const {
    errors,
    handleSubmit,
    setFieldTouched,
    setFieldValue,
    touched,
    values,
  } = handleShipping;

  return (
    <div className="Shipping container mx-auto mt-12">
      <div className="grid grid-cols-12 lg:gap-x-16">
        <div className="col-span-12 md:col-span-8">
          <div className="w-full">
            <h3 className="text-xl font-semibold">SHIPPING METHODS</h3>
            <form onSubmit={handleSubmit}>
              <div className="my-6">
                {shippingProvider && shippingProvider.map((item) => {
                  return (
                    <div className="flex justify-between" key={item.id}>
                      <Checkbox
                        label={item.name}
                        name="shippingMethod"
                        className="mb-2"
                        value={values.shippingMethod}
                        onChange={() => setFieldValue('shippingMethod', item.id)}
                        onBlur={() => setFieldTouched('shippingMethod')}
                        checked={values.shippingMethod === item.id}
                      />
                      <p>{formatAmountWithSymbol({ amount: item.amount, currency: cart?.region?.currency_code })}</p>
                    </div>
                  );
                })}

                {touched.shippingMethod && errors.shippingMethod && (
                  <div className="text-[12px] text-red-500 mt-1">
                    {errors.shippingMethod}
                  </div>
                )}
              </div>

              <div className="mt-12 mb-20">
                <Button type="submit" className="w-full lg:w-1/2">
                  Continue to Payment
                </Button>
              </div>
            </form>
          </div>
        </div>
        <div className="col-span-12 mb-16 md:col-span-4">
          <CartSummary hideButton />
        </div>
      </div>
    </div>
  );
};

export default ShippingMethods;
