import cn from 'classnames';
import Image from 'next/image';
import { variantGetters } from '@react-test-storefront/medusa';
import { useAppProvider } from '@/context/AppProvider';
import { formatAmountWithSymbol } from '@/utils/price';

const CheckoutItem = ({ item }) => {
  const {
    cartObject: { cart }
  } = useAppProvider();
  const itemName = variantGetters.getName(item);
  const coverImage = variantGetters.getCoverImage(item);
  const itemPrice = variantGetters.getPrice(item);
  const itemQty = variantGetters.getQty(item);

  const rootClass = cn('mb-4');
  const thumbClass = cn('relative z-0 overflow-hidden flex-shrink-0 mb-2 md:mb-0 w-12 md:w-16 h-12 md:h-16');
  const titleClass = cn('font-normal');
  const priceClass = cn('font-normal');

  return (
    <div className={rootClass}>
      <div className="flex flex-row w-full overflow-hidden py-4 gap-x-4">
        <div className={thumbClass}>
          <Image
            src={coverImage}
            alt={itemName}
            layout="fill"
            objectFit="cover"
            objectPosition="center"
            unoptimized
          />
        </div>
        <div className="flex flex-col flex-1 w-full">
          <div className="flex flex-col md:flex-row w-full text-base mb-2">
            <div>
              <span className={titleClass}>{itemName}</span>
              <p>x{itemQty}</p>
            </div>
            <div className="flex flex-col justify-between md:ml-auto space-y-2 text-sm">
              <span className={priceClass}>
                {formatAmountWithSymbol({
                  amount: itemPrice.regular,
                  currency: cart?.region?.currency_code,
                  tax: cart?.region?.tax_rate
                })}
              </span>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default CheckoutItem;
