import { useCallback } from 'react';
import { Tabs, TabList, Tab } from '@/components/common/Tabs';
import { SHIPPING, ADDRESS, PAYMENT } from '../constants';

const CheckoutTabs = ({
  shippingActive,
  shippingDisabled,
  addressActive,
  addressDisabled,
  paymentActive,
  paymentDisabled,
  setStep,
}) => {
  /* handler */
  const handleActive = useCallback(
    (step) => {
      setStep(step);
    },
    [setStep]
  );

  /* logic */
  const activePage = (() => {
    switch (true) {
      case addressActive:
        return 0;
      case shippingActive:
        return 1;
      case paymentActive:
        return 2;
      default:
        return 0;
    }
  })();

  return (
    <div>
      <div className="container mx-auto">
        <Tabs active={activePage}>
          <TabList className="flex flex-row">
            <Tab
              index={0}
              disabled={addressDisabled}
              onClick={() => handleActive(ADDRESS)}
            >
              Address
            </Tab>
            <Tab
              index={1}
              disabled={shippingDisabled}
              onClick={() => handleActive(SHIPPING)}
            >
              Shipping
            </Tab>
            <Tab
              index={2}
              disabled={paymentDisabled}
              onClick={() => handleActive(PAYMENT)}
            >
              Payment
            </Tab>
          </TabList>
        </Tabs>
      </div>
    </div>
  );
};

export default CheckoutTabs;
