import { useState } from 'react';
import ProductGrid from '@/components/sections/ProductGrid';
import Layout from '@/components/templates/LayoutApp';
import { useAppProvider } from '@/context/AppProvider';
import { categoryGetters } from '@react-test-storefront/medusa';
// import SortBy from './partials/SortBy';
import FilterCategories from './partials/FilterCategories';
import MobileFilterSheet from './partials/MobileFilterSheet';
import { useFilter } from '@/hooks/useFilter';

const StoreContainer = () => {
  const { searchObject: { searchLoading, result } } = useAppProvider();
  const products = result?.data?.products || [];
  const filterables = categoryGetters.getFilterables(products);
  const [activeFilters, setActiveFilters] = useState(null);
  const filteredProducts = useFilter(products, activeFilters);

  return (
    <Layout title="Shop">
      <div className="container mx-auto mt-8 mb-24">
        <div className="grid grid-cols-1 lg:grid-cols-12 gap-x-6">
          <div className="lg:hidden flex mb-6">
            <MobileFilterSheet
              filterables={filterables}
              activeFilters={activeFilters}
              setActiveFilters={setActiveFilters}
            />
          </div>
          <div className="col-span-1 lg:col-span-3 hidden lg:block">
            {/* <SortBy /> */}
            <FilterCategories
              filterables={filterables}
              activeFilters={activeFilters}
              setActiveFilters={setActiveFilters}
            />
          </div>
          <div className="relative col-span-1 lg:col-span-9">
            {searchLoading &&
              <div className="absolute top-0 left-0 right-0 bottom-0 bg-slate-300/70 flex justify-center align-center py-20">
                Loading...
              </div>
            }
            <ProductGrid products={filteredProducts} gridCount={3} />
          </div>
        </div>
      </div>
    </Layout>
  );
};

export default StoreContainer;
