import React, { useEffect, useMemo, useState } from 'react';
import { Swiper, SwiperSlide } from 'swiper/react';
import { Navigation, FreeMode } from 'swiper';
import Layout from '@/components/templates/LayoutApp';
import ThumbnailCarousel from '@/components/sections/ThumbnailCarousel/ThumbnailCarousel';
// import IconArrowDown from '../../../public/images/icons/icon-arrow-down.svg';
import Quantity from '@/components/sections/Quantity';
import Button from '@/components/common/Button';
// import Rating from '@/components/common/Rating';
import { dummyProducts } from '@/data/products';
import Image from 'next/image';
import useResponsive from '@/hooks/useResponsive';
import TitleDivider from '@/components/sections/TitleDivider';
import { useAppProvider } from '@/context/AppProvider';
import { productGetters } from '@react-test-storefront/medusa';
import { formatAmountWithSymbol } from '@/utils/price';

const StoreDetailContainer = ({ slug }) => {
  const {
    cartObject: { cartFunctions, cart },
    searchObject: { searchFunctions }
  } = useAppProvider();
  const { addItem: addItemToCart } = cartFunctions();
  const responsive = useResponsive();
  const [product, setProduct] = useState(null);
  const [variant, setVariant] = useState(null);
  const [quantity, setQuantity] = useState(1);

  // GETTERS
  const { getName, getPrice, getDescription, getGallery } = productGetters;
  const name = useMemo(() => getName(product), [product]);
  const price = useMemo(() => getPrice(product, cart?.region?.currency_code));
  const description = useMemo(() => getDescription(product));
  const images = useMemo(() => getGallery(product));

  // Get the product from slug
  useEffect(() => {
    async function fetchActiveProduct() {
      const { getProduct } = searchFunctions();
      const productRes = await getProduct({ slug });

      setProduct(productRes);
      setVariant(productRes.variants[0]);
    }
    fetchActiveProduct();
  }, []);

  const handleIncreaseQuantity = (n = 1) => {
    const val = Number(quantity) + n;
    setQuantity(val);
  };

  const handleChange = async ({ target: { value } }) => {
    setQuantity(Number(value));
  };

  const handleAddToCart = () => {
    addItemToCart({
      currentCart: cart,
      product: variant,
      quantity,
    });
  };

  if (!product) {
    return null;
  }

  // const renderBreadcrumbs = () => {
  //   return (
  //     <span className="text-xs uppercase tracking-widest text-gray-500 font-light mb-4 flex items-center md:hidden">
  //       SHOP{' '}
  //       <span className=" text-current -rotate-90 block w-6 h-6 scale-75">
  //         <IconArrowDown />
  //       </span>{' '}
  //       WOMAN
  //     </span>
  //   );
  // };

  return (
    <Layout title={name}>
      <div className="container mx-auto">
        <div className="grid grid-cols-12 md:gap-x-6">
          <div className="col-span-12 md:col-span-6 lg:col-span-5">

            {/* {renderBreadcrumbs()} */}
            <ThumbnailCarousel images={images} />
          </div>
          <div className="col-span-12 md:col-span-6 lg:col-span-7 mt-8 lg:mt-0">
            {/* {renderBreadcrumbs()} */}
            {/* <Rating activeStar={4} className="mb-2" /> */}
            <h1 className="text-4xl">{name}</h1>
            <h3 className="text-2xl mt-2">
              {formatAmountWithSymbol({
                amount: price?.regular,
                currency: cart?.region?.currency_code,
                tax: cart?.region?.tax_rate
              })}
            </h3>
            <p className="mt-8">{description}</p>
            <div className="mt-11 w-full">
              <Quantity
                value={quantity}
                handleChange={handleChange}
                increase={() => handleIncreaseQuantity(1)}
                decrease={() => handleIncreaseQuantity(-1)}
              />
            </div>
            <div className="my-6">
              <Button width="100%" onClick={handleAddToCart}>
                ADD TO CART
              </Button>
            </div>
          </div>
          <div className="col-span-12 pt-8 pb-16">
            <TitleDivider title="SIMILAR PRODUCT" />
            <Swiper
              modules={[Navigation, FreeMode]}
              navigation={responsive.isLg}
              freeMode={!responsive.isLg}
              slidesPerView={1.2}
              spaceBetween={15}
              breakpoints={{
                768: {
                  slidesPerView: 4,
                },
              }}
              className="swiper-product-recommend"
            >
              {dummyProducts.map((product) => (
                <SwiperSlide key={product.path} className="flex justify-center">
                  <div className="w-[180px] flex flex-col items-center">
                    <div className="w-full h-[180px] relative overflow-hidden mb-3">
                      <Image
                        src={product.image}
                        alt={product.name}
                        layout="fill"
                        objectFit="cover"
                      />
                    </div>
                    <div className="text-[12px] font-semibold">
                      {product.name}
                    </div>
                    <div className="text-[12px]">{product.price}</div>
                  </div>
                </SwiperSlide>
              ))}
            </Swiper>
          </div>
        </div>
      </div>
    </Layout>
  );
};

export default StoreDetailContainer;
