import { createApiClient } from '@react-test-storefront/medusa-api';
import {
  cartMethods,
  shippingMethods,
  billingMethods,
  makeOrderMethods,
  searchMethods,
  shippingRegionMethods,
  shippingProviderMethods,
  useShippingRegionFactory,
  paymentMethods,
} from '@react-test-storefront/medusa';
import {
  useCartFactory,
  useShippingFactory,
  useBillingFactory,
  usePaymentFactory,
  useMakeOrderFactory,
  useSearchFactory,
  useShippingProviderFactory
} from '@react-test-storefront/core';
import { useEffect, useState } from 'react';
import { useAppProvider } from '.';

const InitializeFactories = ({ children }) => {
  const [appLoaded, setAppLoaded] = useState(false);
  const context = useAppProvider();

  // Create a new context object to be used around the app.
  useEffect(() => {
    const apiConfig = {
      apiUrl: process.env.MEDUSA_API_URL
    };
    const { api, client, settings } = createApiClient(context, apiConfig);
    context.setSettings(settings);
    context.setApi(api);
    context.setClient(() => client);
    // eslint-disable-next-line
  }, []);

  // After we load the API and all the functions we should start loading the cart and other elements that require
  useEffect(() => {
    if (context.api && context.client && !appLoaded) {
      const useCart = useCartFactory(context, cartMethods);

      useShippingFactory(context, shippingMethods);
      useShippingRegionFactory(context, shippingRegionMethods);
      useShippingProviderFactory(context, shippingProviderMethods);
      useBillingFactory(context, billingMethods);
      useMakeOrderFactory(context, makeOrderMethods);
      useSearchFactory(context, searchMethods);
      usePaymentFactory(context, paymentMethods);

      // Add loaders
      const { load: loadCart } = useCart();
      loadCart();

      setAppLoaded(true);
    }
  }, [appLoaded, context.api, context]);

  if (!appLoaded) return null;

  return children;
};

export default InitializeFactories;
