import { createContext, useContext, useEffect, useState } from 'react';

const AppContext = createContext();

export function AppProvider({ children }) {
  const [api, setApi] = useState(null);
  const [client, setClient] = useState(null);
  const [settings, setSettings] = useState(null);

  // Cart
  const [cart, setCart] = useState(null);
  const [cartError, setCartError] = useState({
    addItem: null,
    removeItem: null,
    updateItemQty: null,
    load: null,
    clear: null,
    applyCoupon: null,
    removeCoupon: null,
  });
  const [cartLoading, setCartLoading] = useState(null);
  const [composable, setComposable] = useState(null);
  const [cartFunctions, setCartFunctions] = useState({});

  // Shipping
  const [shipping, setShipping] = useState(null);
  const [shippingFunctions, setShippingFunctions] = useState({});
  const [shippingLoading, setShippingLoading] = useState(null);
  const [shippingError, setShippingError] = useState({
    load: null,
    save: null,
  });
  // Shipping provider
  const [shippingProvider, setShippingProvider] = useState(null);
  const [shippingProviderFunctions, setShippingProviderFunctions] = useState({});
  const [shippingProviderLoading, setShippingProviderLoading] = useState(null);
  const [shippingProviderError, setShippingProviderError] = useState({
    load: null,
    save: null,
  });
  // Shipping regions
  const [shippingRegion, setShippingRegion] = useState(null);
  const [shippingRegionFunctions, setShippingRegionFunctions] = useState({});
  const [shippingRegionLoading, setShippingRegionLoading] = useState(null);
  const [shippingRegionError, setShippingRegionError] = useState({
    load: null,
    save: null,
  });
  // Billing
  const [billing, setBilling] = useState(null);
  const [billingFunctions, setBillingFunctions] = useState({});
  const [billingLoading, setBillingLoading] = useState(null);
  const [billingError, setBillingError] = useState({
    load: null,
    save: null,
  });
  // Order
  const [order, setOrder] = useState(null);
  const [orderFunctions, setOrderFunctions] = useState({});
  const [orderLoading, setOrderLoading] = useState(null);
  const [orderError, setOrderError] = useState({
    make: null,
  });
  const [payment, setPayment] = useState(null);
  const [paymentFunctions, setPaymentFunctions] = useState({});
  const [paymentOptions, setPaymentOptions] = useState(null);
  const [paymentLoading, setPaymentLoading] = useState(null);
  const [paymentError, setPaymentError] = useState({
    load: null,
    update: null,
    remove: null,
    select: null,
  });
  // Search
  const [result, setResult] = useState({
    input: null,
    data: null,
  });
  const [filters, setFilters] = useState({});
  const [searchFunctions, setSearchFunctions] = useState(null);
  const [searchLoading, setSearchLoading] = useState(null);
  const [searchError, setSearchError] = useState({
    search: null,
  });

  // When the app loads fetch all the products
  useEffect(() => {
    if (searchFunctions && !result.data && !searchLoading) {
      const { search } = searchFunctions();

      if (search) {
        search();
      }
    }
  }, [searchFunctions, result.data, searchLoading]);

  const sharedState = {
    api,
    setApi,
    client,
    setClient,
    settings,
    setSettings,

    // CART
    cartObject: {
      cart,
      setCart,
      cartFunctions,
      setCartFunctions,
      cartError,
      setCartError,
      cartLoading,
      setCartLoading,
      composable,
      setComposable,
    },
    // Shipping
    shippingObject: {
      shipping,
      setShipping,
      shippingFunctions,
      setShippingFunctions,
      shippingLoading,
      setShippingLoading,
      shippingError,
      setShippingError,
    },
    // Shipping provider
    shippingProviderObject: {
      shippingProvider,
      setShippingProvider,
      shippingProviderFunctions,
      setShippingProviderFunctions,
      shippingProviderLoading,
      setShippingProviderLoading,
      shippingProviderError,
      setShippingProviderError,
    },
    // Shipping region
    shippingRegionObject: {
      shippingRegion,
      setShippingRegion,
      shippingRegionFunctions,
      setShippingRegionFunctions,
      shippingRegionLoading,
      setShippingRegionLoading,
      shippingRegionError,
      setShippingRegionError,
    },
    // Billing
    billingObject: {
      billing,
      setBilling,
      billingFunctions,
      setBillingFunctions,
      billingLoading,
      setBillingLoading,
      billingError,
      setBillingError,
    },
    // Payment
    paymentObject: {
      payment,
      setPayment,
      paymentFunctions,
      setPaymentFunctions,
      paymentOptions,
      setPaymentOptions,
      paymentLoading,
      setPaymentLoading,
      paymentError,
      setPaymentError,
    },
    // Order
    orderObject: {
      order,
      setOrder,
      orderError,
      setOrderError,
      orderFunctions,
      setOrderFunctions,
      orderLoading,
      setOrderLoading,
    },
    // Search
    searchObject: {
      filters,
      setFilters,
      result,
      setResult,
      searchError,
      setSearchError,
      searchLoading,
      setSearchLoading,
      searchFunctions,
      setSearchFunctions
    }
  };

  return (
    <AppContext.Provider value={sharedState}>{children}</AppContext.Provider>
  );
}

export function useAppProvider() {
  return useContext(AppContext);
}
