import LayoutApp from '@/components/templates/LayoutApp';
import { serverSideTranslations } from 'next-i18next/serverSideTranslations';
import Image from 'next/image';

function Error({ statusCode }) {
  const renderTitleWithStatus = (() => {
    switch (statusCode) {
      case 404:
        return 'Page not found ';
      default:
        return 'An error occurred on server';
    }
  })();

  return (
    <LayoutApp title="Home">
      <div className="container mx-auto mt-8 mb-24 min-h-[180px] text-center">
        <div className="w-full h-[180px] sm:w-[320px] sm:h-[380px] lg:w-[640px] lg:h-[420px] relative overflow-hidden mx-auto mb-6">
          <Image
            src="/images/misc/error-placeholder.svg"
            alt=""
            layout="fill"
            objectFit="contain"
          />
        </div>
        <h1 className="text-black font-semibold text-2xl md:text-4xl mb-3">
          {statusCode
            ? renderTitleWithStatus
            : 'An error occurred on client'}
        </h1>
        <p className="text-gray-400">We are sorry that we can’t find the page, please go back or try again</p>
      </div>
    </LayoutApp>
  );
}

export const getServerSideProps = async ({ res, err, locale }) => {
  const statusCode = res ? res.statusCode : err ? err.statusCode : 404;
  return {
    props: {
      statusCode,
      // locales multi language
      ...(await serverSideTranslations(locale, ['header', 'common']))
    }
  };
};

export default Error;
