import React from 'react';
import { NextSeo } from 'next-seo';

function SearchEngineOptimization({ description = '', meta = [], title = '' }) {
  const defaultTitle = process.env.SITE_TITLE;
  const metaDescription = description || process.env.SITE_DESCRIPTION;

  return (
    <NextSeo
      title={title}
      titleTemplate={defaultTitle ? `%s | ${defaultTitle}` : null}
      meta={[
        {
          name: 'description',
          content: metaDescription,
        },
        {
          property: 'og:title',
          content: title,
        },
        {
          property: 'og:description',
          content: metaDescription,
        },
        {
          property: 'og:type',
          content: 'website',
        },
        {
          name: 'twitter:card',
          content: 'summary',
        },
        {
          name: 'twitter:creator',
          content: process.env.SITE_AUTHOR || '',
        },
        {
          name: 'twitter:title',
          content: title,
        },
        {
          name: 'twitter:description',
          content: metaDescription,
        },
      ].concat(meta)}
    />
  );
}

export default SearchEngineOptimization;
